scDenorm
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

``` python
!which python
```

    /home/huang_yin/anaconda3/envs/sc/bin/python

This file will become your README and also the index of your
documentation.

## Install

``` sh
pip install scDenorm
```

## How to use

### In jupyter

``` python
scdenorm('scaled.mtx',fout='scd_scaled.h5ad',base=np.e)
```

    100%|██████████| 9/9 [00:00<00:00, 1304.79it/s]

### In command line

``` python
!scdenorm scaled.mtx --fout scd_scaled_c.h5ad
```
